@@ -19,9 +19,14 @@
 /*
  * Sensor data conversion functions
  */
-package org.altusmetrum.altoslib_11;
+package org.altusmetrum.altoslib_12;
+
+import java.util.*;
 
 public class AltosConvert {
+
+	public static final double gravity = 9.80665;
+
 	/*
 	 * Pressure Sensor Model, version 1.1
 	 *
@@ -42,20 +47,20 @@ public class AltosConvert {
 	 *   in Joules/(kilogram-Kelvin).
 	 */
 
-	public static final double GRAVITATIONAL_ACCELERATION = -9.80665;
-	public static final double AIR_GAS_CONSTANT		= 287.053;
-	public static final double NUMBER_OF_LAYERS		= 7;
-	public static final double MAXIMUM_ALTITUDE		= 84852.0;
-	public static final double MINIMUM_PRESSURE		= 0.3734;
-	public static final double LAYER0_BASE_TEMPERATURE	= 288.15;
-	public static final double LAYER0_BASE_PRESSURE	= 101325;
+	private static final double GRAVITATIONAL_ACCELERATION = -gravity;
+	private static final double AIR_GAS_CONSTANT		= 287.053;
+	private static final double NUMBER_OF_LAYERS		= 7;
+	private static final double MAXIMUM_ALTITUDE		= 84852.0;
+	private static final double MINIMUM_PRESSURE		= 0.3734;
+	private static final double LAYER0_BASE_TEMPERATURE	= 288.15;
+	private static final double LAYER0_BASE_PRESSURE	= 101325;
 
 	/* lapse rate and base altitude for each layer in the atmosphere */
-	public static final double[] lapse_rate = {
+	private static final double[] lapse_rate = {
 		-0.0065, 0.0, 0.001, 0.0028, 0.0, -0.0028, -0.002
 	};
 
-	public static final int[] base_altitude = {
+	private static final int[] base_altitude = {
 		0, 11000, 20000, 32000, 47000, 51000, 71000
 	};
 
@@ -179,6 +184,18 @@ public class AltosConvert {
 		return altitude;
 	}
 
+	public static double degrees_to_radians(double degrees) {
+		if (degrees == AltosLib.MISSING)
+			return AltosLib.MISSING;
+		return degrees * (Math.PI / 180.0);
+	}
+
+	public static double radians_to_degrees(double radians) {
+		if (radians == AltosLib.MISSING)
+			return AltosLib.MISSING;
+		return radians * (180.0 / Math.PI);
+	}
+
 	public static double
 	cc_battery_to_voltage(double battery)
 	{
@@ -186,7 +203,7 @@ public class AltosConvert {
 	}
 
 	public static double
-	cc_ignitor_to_voltage(double ignite)
+	cc_igniter_to_voltage(double ignite)
 	{
 		return ignite / 32767 * 15.0;
 	}
@@ -219,7 +236,23 @@ public class AltosConvert {
 		return AltosLib.MISSING;
 	}
 
-	static double tele_mini_voltage(int sensor) {
+	static double tele_mini_3_adc(int raw) {
+		return raw / 4095.0;
+	}
+
+	static public double tele_mini_3_battery_voltage(int v_batt) {
+		if (v_batt != AltosLib.MISSING)
+			return 3.3 * tele_mini_3_adc(v_batt) * (5.6 + 10.0) / 10.0;
+		return AltosLib.MISSING;
+	}
+
+	static double tele_mini_3_pyro_voltage(int raw) {
+		if (raw != AltosLib.MISSING)
+			return 3.3 * tele_mini_3_adc(raw) * (100.0 + 27.0) / 27.0;
+		return AltosLib.MISSING;
+	}
+
+	static double tele_mini_2_voltage(int sensor) {
 		double	supply = 3.3;
 
 		return sensor / 32767.0 * supply * 127/27;
@@ -237,7 +270,15 @@ public class AltosConvert {
 		return 3.3 * mega_adc(raw) * (5.1 + 10.0) / 10.0;
 	}
 
-	static double easy_mini_voltage(int sensor, int serial) {
+	static double easy_mini_2_adc(int raw) {
+		return raw / 4095.0;
+	}
+
+	static double easy_mini_1_adc(int raw) {
+		return raw / 32767.0;
+	}
+
+	static double easy_mini_1_voltage(int sensor, int serial) {
 		double	supply = 3.3;
 		double	diode_offset = 0.0;
 
@@ -251,7 +292,13 @@ public class AltosConvert {
 		if (serial < 1665)
 			diode_offset = 0.150;
 
-		return sensor / 32767.0 * supply * 127/27 + diode_offset;
+		return easy_mini_1_adc(sensor) * supply * 127/27 + diode_offset;
+	}
+
+	static double easy_mini_2_voltage(int sensor) {
+		double	supply = 3.3;
+
+		return easy_mini_2_adc(sensor) * supply * 127/27;
 	}
 
 	public static double radio_to_frequency(int freq, int setting, int cal, int channel) {
@@ -289,6 +336,10 @@ public class AltosConvert {
 		return 434.550 + channel * 0.100;
 	}
 
+	public static int telem_to_rssi(int telem) {
+		return telem / 2 - 74;
+	}
+
 	public static int[] ParseHex(String line) {
 		String[] tokens = line.split("\\s+");
 		int[] array = new int[tokens.length];
@@ -350,12 +401,52 @@ public class AltosConvert {
 		return (c - 32) * 5/9;
 	}
 
+	public static double psi_to_pa(double psi) {
+		return psi * 6894.76;
+	}
+
+	public static double pa_to_psi(double pa) {
+		return pa / 6894.76;
+	}
+
+	public static double n_to_lb(double n) {
+		return n * 0.22480894;
+	}
+
+	public static double lb_to_n(double lb) {
+		return lb / 0.22480894;
+	}
+
+	public static double acceleration_from_sensor(double sensor, double plus_g, double minus_g, double ground) {
+
+		if (sensor == AltosLib.MISSING)
+			return AltosLib.MISSING;
+
+		if (plus_g == AltosLib.MISSING || minus_g == AltosLib.MISSING)
+			return AltosLib.MISSING;
+
+		if (ground == AltosLib.MISSING)
+			ground = plus_g;
+
+		double counts_per_g = (plus_g - minus_g) / 2.0;
+		double counts_per_mss = counts_per_g / gravity;
+
+		if (counts_per_mss == 0)
+			return AltosLib.MISSING;
+
+		return (sensor - ground) / counts_per_mss;
+	}
+
 	public static boolean imperial_units = false;
 
 	public static AltosDistance distance = new AltosDistance();
 
 	public static AltosHeight height = new AltosHeight();
 
+	public static AltosPressure pressure = new AltosPressure();
+
+	public static AltosForce force = new AltosForce();
+
 	public static AltosSpeed speed = new AltosSpeed();
 
 	public static AltosAccel accel = new AltosAccel();
@@ -370,6 +461,14 @@ public class AltosConvert {
 
 	public static AltosLongitude longitude = new AltosLongitude();
 
+	public static AltosRotationRate rotation_rate = new AltosRotationRate();
+
+	public static AltosStateName state_name = new AltosStateName();
+
+	public static AltosPyroName pyro_name = new AltosPyroName();
+
+	public static AltosUnits magnetic_field = null;
+
 	public static String show_gs(String format, double a) {
 		a = meters_to_g(a);
 		format = format.concat(" g");
@@ -387,6 +486,13 @@ public class AltosConvert {
 		return csum & 0xff;
 	}
 
+	public static int checksum(List<Byte> data, int start, int length) {
+		int	csum = 0x5a;
+		for (int i = 0; i < length; i++)
+			csum += data.get(i+start);
+		return csum & 0xff;
+	}
+
 	public static double beep_value_to_freq(int value) {
 		if (value == 0)
 			return 4000;
