@@ -43,6 +43,8 @@ public abstract class AltosLink implements Runnable {
 	public LinkedBlockingQueue<AltosLine> reply_queue = new LinkedBlockingQueue<AltosLine>();
 	public LinkedBlockingQueue<byte[]> binary_queue = new LinkedBlockingQueue<byte[]>();
 
+	private String match_string = null;
+
 	public synchronized void add_monitor(LinkedBlockingQueue<AltosLine> q) {
 		set_monitor(true);
 		monitors.add(q);
@@ -112,6 +114,15 @@ public abstract class AltosLink implements Runnable {
 
 	private int	len_read = 0;
 
+	private boolean match_bytes(byte[] bytes, int byte_count, String match) {
+		if (byte_count < match.length())
+			return false;
+		String	line = new String(bytes, 0, byte_count, AltosLib.unicode_set);
+		if (line == null)
+			return false;
+		return line.indexOf(match) >= 0;
+	}
+
 	public void run () {
 		int c;
 		byte[] line_bytes = null;
@@ -159,6 +170,11 @@ public abstract class AltosLink implements Runnable {
 							line_count = 0;
 							len_read = 0;
 						}
+						if (match_string != null && match_bytes(line_bytes, line_count, match_string)) {
+							match_string = null;
+							add_bytes(line_bytes, line_count);
+							line_count = 0;
+						}
 					}
 				}
 			}
@@ -166,6 +182,9 @@ public abstract class AltosLink implements Runnable {
 		}
 	}
 
+	public void set_match(String match) {
+		match_string = match;
+	}
 
 	public String get_reply(int timeout) throws InterruptedException {
 		boolean	can_cancel = can_cancel_reply();
@@ -336,7 +355,8 @@ public abstract class AltosLink implements Runnable {
 	public int telemetry_rate = -1;
 	public double frequency;
 	public String callsign;
-	AltosConfigData	config_data;
+	private AltosConfigData	config_data_local;
+	private AltosConfigData config_data_remote;
 
 	private Object config_data_lock = new Object();
 
@@ -371,7 +391,7 @@ public abstract class AltosLink implements Runnable {
 
 	public void set_radio_frequency(double in_frequency) throws InterruptedException, TimeoutException {
 		frequency = in_frequency;
-		config_data();
+		AltosConfigData config_data = config_data();
 		set_radio_frequency(frequency,
 				    config_data.radio_frequency > 0,
 				    config_data.radio_setting > 0,
@@ -427,11 +447,24 @@ public abstract class AltosLink implements Runnable {
 
  	public AltosConfigData config_data() throws InterruptedException, TimeoutException {
 		synchronized(config_data_lock) {
-			if (config_data == null) {
-				printf("m 0\n");
-				config_data = new AltosConfigData(this);
-				if (monitor_mode)
-					set_monitor(true);
+			AltosConfigData	config_data;
+
+			if (remote) {
+				if (config_data_remote == null) {
+					printf("m 0\n");
+					config_data_remote = new AltosConfigData(this);
+					if (monitor_mode)
+						set_monitor(true);
+				}
+				config_data = config_data_remote;
+			} else {
+				if (config_data_local == null) {
+					printf("m 0\n");
+					config_data_local = new AltosConfigData(this);
+					if (monitor_mode)
+						set_monitor(true);
+				}
+				config_data = config_data_local;
 			}
 			return config_data;
 		}
@@ -532,14 +565,23 @@ public abstract class AltosLink implements Runnable {
 	}
 
 	public boolean has_monitor_battery() {
-		return config_data.has_monitor_battery();
+		try {
+			return config_data().has_monitor_battery();
+		} catch (InterruptedException ie) {
+			return false;
+		} catch (TimeoutException te) {
+			return false;
+		}
 	}
 
 	public double monitor_battery() throws InterruptedException {
-		int monitor_batt = AltosLib.MISSING;
+		double	volts = AltosLib.MISSING;
 
-		if (config_data.has_monitor_battery()) {
-			try {
+		try {
+			AltosConfigData config_data = config_data();
+			int monitor_batt = AltosLib.MISSING;
+
+			if (config_data.has_monitor_battery()) {
 				String[] items = adc();
 				for (int i = 0; i < items.length;) {
 					if (items[i].equals("batt")) {
@@ -549,19 +591,17 @@ public abstract class AltosLink implements Runnable {
 					}
 					i++;
 				}
-			} catch (TimeoutException te) {
 			}
-		}
-		if (monitor_batt == AltosLib.MISSING)
-			return AltosLib.MISSING;
+			if (monitor_batt != AltosLib.MISSING) {
+				if (config_data.product.startsWith("TeleBT-v3") || config_data.product.startsWith("TeleBT-v4")) {
+					volts = AltosConvert.tele_bt_3_battery(monitor_batt);
+				} else {
+					volts = AltosConvert.cc_battery_to_voltage(monitor_batt);
+				}
+			}
 
-		double	volts = AltosLib.MISSING;
-		if (config_data.product.startsWith("TeleBT-v3") || config_data.product.startsWith("TeleBT-v4")) {
-			volts = AltosConvert.tele_bt_3_battery(monitor_batt);
-		} else {
-			volts = AltosConvert.cc_battery_to_voltage(monitor_batt);
+		} catch (TimeoutException te) {
 		}
-
 		return volts;
 	}
 
