@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_11;
+package org.altusmetrum.altoslib_12;
 
 import java.util.concurrent.TimeoutException;
 
@@ -26,15 +26,25 @@ public class AltosSensorEMini {
 	public int	main;
 	public int	batt;
 
-	static public void update_state(AltosState state, AltosLink link, AltosConfigData config_data) throws InterruptedException {
+	static public void provide_data(AltosDataListener listener, AltosLink link, int version) throws InterruptedException {
 		try {
 			AltosSensorEMini	sensor_emini = new AltosSensorEMini(link);
+			AltosCalData		cal_data = listener.cal_data();
 
 			if (sensor_emini == null)
 				return;
-			state.set_battery_voltage(AltosConvert.easy_mini_voltage(sensor_emini.batt, config_data.serial));
-			state.set_apogee_voltage(AltosConvert.easy_mini_voltage(sensor_emini.apogee, config_data.serial));
-			state.set_main_voltage(AltosConvert.easy_mini_voltage(sensor_emini.main, config_data.serial));
+			switch (version) {
+			case 1:
+				listener.set_battery_voltage(AltosConvert.easy_mini_1_voltage(sensor_emini.batt, cal_data.serial));
+				listener.set_apogee_voltage(AltosConvert.easy_mini_1_voltage(sensor_emini.apogee, cal_data.serial));
+				listener.set_main_voltage(AltosConvert.easy_mini_1_voltage(sensor_emini.main, cal_data.serial));
+				break;
+			case 2:
+				listener.set_battery_voltage(AltosConvert.easy_mini_2_voltage(sensor_emini.batt));
+				listener.set_apogee_voltage(AltosConvert.easy_mini_2_voltage(sensor_emini.apogee));
+				listener.set_main_voltage(AltosConvert.easy_mini_2_voltage(sensor_emini.main));
+				break;
+			}
 
 		} catch (TimeoutException te) {
 		}
