@@ -40,7 +40,7 @@ public class AltosTelemetryConfiguration extends AltosTelemetryStandard {
 
 		AltosCalData cal_data = listener.cal_data();
 
-		cal_data.set_device_type(device_type());
+		listener.set_device_type(device_type());
 		cal_data.set_flight(flight());
 		cal_data.set_config(config_major(), config_minor(), flight_log_max());
 		if (device_type() == AltosLib.product_telegps)
