@@ -16,7 +16,7 @@
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
  */
 
-package org.altusmetrum.altoslib_11;
+package org.altusmetrum.altoslib_12;
 
 import java.text.*;
 
@@ -41,6 +41,10 @@ public abstract class AltosUnits {
 
 	public abstract double inverse(double v, boolean imperial_units);
 
+	public String string_value(double v, boolean imperial_units) {
+		return new Double(value(v, imperial_units)).toString();
+	}
+
 	public abstract String show_units(boolean imperial_units);
 
 	public abstract String say_units(boolean imperial_units);
@@ -113,6 +117,10 @@ public abstract class AltosUnits {
 		return say_units(v, AltosConvert.imperial_units);
 	}
 
+	public String string_value(double v) {
+		return string_value(v, AltosConvert.imperial_units);
+	}
+
 	/* Parsing functions. Use the first range of the type */
 	public String parse_units(boolean imperial_units) {
 		return first_range(imperial_units).show_units;
