@@ -36,7 +36,7 @@ import org.jfree.chart.labels.*;
 import org.jfree.data.xy.*;
 import org.jfree.data.*;
 
-public class AltosUIGraph implements AltosUnitsListener {
+public class AltosUIGraph implements AltosUnitsListener, AltosShapeListener {
 
 	XYPlot				plot;
 	JFreeChart			chart;
@@ -56,14 +56,14 @@ public class AltosUIGraph implements AltosUnitsListener {
 		return panel;
 	}
 
-	public AltosUIAxis newAxis(String label, AltosUnits units, Color color, int flags) {
-		AltosUIAxis axis = new AltosUIAxis(label, units, color, axis_index++, flags);
+	public AltosUIAxis newAxis(String label, AltosUnits units, AltosUILineStyle line_style, int flags) {
+		AltosUIAxis axis = new AltosUIAxis(label, units, line_style, axis_index++, flags);
 		plot.setRangeAxis(axis.index, axis);
 		return axis;
 	}
 
-	public AltosUIAxis newAxis(String label, AltosUnits units, Color color) {
-		return newAxis(label, units, color, AltosUIAxis.axis_default);
+	public AltosUIAxis newAxis(String label, AltosUnits units, AltosUILineStyle line_style) {
+		return newAxis(label, units, line_style, AltosUIAxis.axis_default);
 	}
 
 	void addAxis(AltosUIAxis axis) {
@@ -95,6 +95,20 @@ public class AltosUIGraph implements AltosUnitsListener {
 			s.set_units();
 	}
 
+	public void filter_changed() {
+		units_changed(false);
+	}
+
+	public void set_shapes_visible(boolean visible) {
+		for (AltosUITimeSeries s : series)
+			s.set_shapes_visible(visible);
+	}
+
+	public void set_line_width(float width) {
+		for (AltosUITimeSeries s : series)
+			s.set_line_width(width);
+	}
+
 	public void setName (String name) {
 		chart.setTitle(name);
 	}
@@ -123,6 +137,8 @@ public class AltosUIGraph implements AltosUnitsListener {
 		this.series = null;
 		this.axis_index = 0;
 
+		enable.register_shape_listener(this);
+
 		axes_added = new Hashtable<Integer,Boolean>();
 
 		xAxis = new NumberAxis("Time (s)");
