@@ -75,6 +75,27 @@ altos_putchar(struct altos_file *file, char c)
 	return ret;
 }
 
+struct bt_vendor_map {
+	char	vendor[10];
+	int	port;
+};
+
+static const struct bt_vendor_map altos_bt_vendor_map[] = {
+	{ .vendor = "00:12:6f:", 1 },	/* Rayson */
+	{ .vendor = "8C:DE:52:", 6 },	/* ISSC */
+	{ .vendor = "D8:80:39:", 6 },	/* Microchip */
+};
+
+#define NUM_BT_VENDOR_MAP	(sizeof altos_bt_vendor_map / sizeof altos_bt_vendor_map[0])
+#define BT_PORT_DEFAULT		1
+
+int altos_bt_port(struct altos_bt_device *device) {
+	unsigned i;
+	for (i = 0; i < NUM_BT_VENDOR_MAP; i++)
+		if (strncmp (device->addr, altos_bt_vendor_map[i].vendor, strlen(altos_bt_vendor_map[i].vendor)) == 0)
+			return altos_bt_vendor_map[i].port;
+	return BT_PORT_DEFAULT;
+}
 
 PUBLIC void
 altos_free(struct altos_file *file)
