@@ -3,7 +3,8 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; version 2 of the License.
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -23,7 +24,6 @@
 void main(void)
 {
 	ao_led_init(LEDS_AVAILABLE);
-	ao_led_on(AO_LED_RED);
 	ao_clock_init();
 	ao_task_init();
 	ao_timer_init();
@@ -35,7 +35,5 @@ void main(void)
 
 	ao_trng_send_init();
 
-	ao_led_off(AO_LED_RED);
-
 	ao_start_scheduler();
 }
