@@ -78,6 +78,7 @@ typedef AO_PORT_TYPE ao_port_t;
 #define AO_PANIC_SELF_TEST_CC1120	0x40 | 1	/* Self test failure */
 #define AO_PANIC_SELF_TEST_HMC5883	0x40 | 2	/* Self test failure */
 #define AO_PANIC_SELF_TEST_MPU6000	0x40 | 3	/* Self test failure */
+#define AO_PANIC_SELF_TEST_MPU9250	0x40 | 3	/* Self test failure */
 #define AO_PANIC_SELF_TEST_MS5607	0x40 | 4	/* Self test failure */
 
 /* Stop the operating system, beeping and blinking the reason */
@@ -217,6 +218,9 @@ ao_cmd_register(const __code struct ao_cmds *cmds);
 void
 ao_cmd_init(void);
 
+void
+ao_cmd(void);
+
 #if HAS_CMD_FILTER
 /*
  * Provided by an external module to filter raw command lines
