@@ -139,7 +139,7 @@ static inline uint32_t set_toggle(uint32_t 	current_value,
 
 static inline uint32_t *ao_usb_packet_buffer_addr(uint16_t sram_addr)
 {
-	return (uint32_t *) (stm_usb_sram + 2 * sram_addr);
+	return (uint32_t *) (((void *) ((uint8_t *) stm_usb_sram + 2 * sram_addr)));
 }
 
 static inline uint32_t ao_usb_epr_stat_rx(uint32_t epr) {
@@ -174,7 +174,7 @@ static inline uint32_t ao_usb_epr_dtog_tx(uint32_t epr) {
  * Set current device address and mark the
  * interface as active
  */
-void
+static void
 ao_usb_set_address(uint8_t address)
 {
 	debug("ao_usb_set_address %02x\n", address);
@@ -598,7 +598,7 @@ ao_usb_ep0_in_start(uint16_t max)
 	ao_usb_ep0_flush();
 }
 
-static struct ao_usb_line_coding ao_usb_line_coding = {115200, 0, 0, 8};
+struct ao_usb_line_coding ao_usb_line_coding = {115200, 0, 0, 8};
 
 /* Walk through the list of descriptors and find a match
  */
@@ -1015,7 +1015,7 @@ ao_usb_enable(void)
 	ao_arch_block_interrupts();
 
 	/* Route interrupts */
-	stm_nvic_set_priority(STM_ISR_USB_LP_POS, 3);
+	stm_nvic_set_priority(STM_ISR_USB_LP_POS, AO_STM_NVIC_LOW_PRIORITY);
 	stm_nvic_set_enable(STM_ISR_USB_LP_POS);
 
 	ao_usb_configuration = 0;
@@ -1109,7 +1109,7 @@ struct ao_usb_dbg {
 	int		line;
 	char		*msg;
 	uint32_t	value;
-	uint32_t	primask;
+	uint32_t	prival;
 #if TX_DBG
 	uint16_t	in_count;
 	uint32_t	in_epr;
@@ -1125,19 +1125,23 @@ struct ao_usb_dbg {
 #endif
 };
 
-#define NUM_USB_DBG	128
+#define NUM_USB_DBG	16
 
-static struct ao_usb_dbg dbg[128];
+static struct ao_usb_dbg dbg[NUM_USB_DBG];
 static int dbg_i;
 
 static void _dbg(int line, char *msg, uint32_t value)
 {
-	uint32_t	primask;
+	uint32_t	prival;
 	dbg[dbg_i].line = line;
 	dbg[dbg_i].msg = msg;
 	dbg[dbg_i].value = value;
-	asm("mrs %0,primask" : "=&r" (primask));
-	dbg[dbg_i].primask = primask;
+#if AO_NONMASK_INTERRUPT
+	asm("mrs %0,basepri" : "=&r" (prival));
+#else
+	asm("mrs %0,primask" : "=&r" (prival));
+#endif
+	dbg[dbg_i].prival = prival;
 #if TX_DBG
 	dbg[dbg_i].in_count = in_count;
 	dbg[dbg_i].in_epr = stm_usb.epr[AO_USB_IN_EPR];
