@@ -94,13 +94,18 @@ extern const uint32_t ao_radio_cal;
  * For the stm32f042, we want to use the USB-based HSI48 clock
  */
 
-#if AO_HSI48
-
-#define AO_SYSCLK	48000000
-#define AO_HCLK		(AO_SYSCLK / AO_AHB_PRESCALER)
-
+#ifndef AO_SYSCLK
+#if AO_HSI
+#define AO_SYSCLK	STM_HSI_FREQ
 #endif
 
+#if AO_HSI48
+#define AO_SYSCLK	48000000
+#endif
+#endif
+
+#define AO_HCLK		(AO_SYSCLK / AO_AHB_PRESCALER)
+
 #if AO_HSE || AO_HSI
 
 #if AO_HSE
@@ -144,10 +149,17 @@ ao_adc_init();
 /* ADC maximum reported value */
 #define AO_ADC_MAX			4095
 
-#define AO_BOOT_APPLICATION_BASE	((uint32_t *) 0x08001000)
-#define AO_BOOT_APPLICATION_BOUND	((uint32_t *) (0x08000000 + stm_flash_size()))
-#define AO_BOOT_LOADER_BASE		((uint32_t *) 0x08000000)
+#ifndef HAS_BOOT_LOADER
 #define HAS_BOOT_LOADER			1
+#endif
+
+#if HAS_BOOT_LOADER
+#define AO_BOOT_APPLICATION_BASE	((uint32_t *) 0x08001000)
+#ifndef AO_BOOT_APPLICATION_BOUND
+#define AO_BOOT_APPLICATION_BOUND	((uint32_t *) (0x08000000 + stm_flash_size()))
+#endif
+#define AO_BOOT_LOADER_BASE		((uint32_t *) 0x08000000)
+#endif
 
 #endif /* _AO_ARCH_H_ */
 
