@@ -17,54 +17,44 @@
  */
 
 #include <ao.h>
+#include <ao_log.h>
 #include <ao_exti.h>
-#include <ao_fat.h>
-#include <ao_eeprom.h>
-
-uint16_t	ao_flight_number = 1;
+#include <ao_tracker.h>
 
 int
 main(void)
 {
 	ao_clock_init();
-	
-#if HAS_STACK_GUARD
-	ao_mpu_init();
-#endif
-
 	ao_task_init();
-//	ao_led_init(LEDS_AVAILABLE);
-//	ao_led_on(AO_LED_RED);
+	ao_cmd_init();
+	ao_config_init();
+
+	ao_led_init(LEDS_AVAILABLE);
+	ao_led_on(AO_LED_GREEN);
+
+	/* internal systems */
 	ao_timer_init();
-
-
-	ao_spi_init();
 	ao_dma_init();
 	ao_exti_init();
 
-	ao_eeprom_init();
-
+	/* SoC hardware */
+	ao_adc_init();
 	ao_serial_init();
-
-	ao_cmd_init();
-
+	ao_spi_init();
 	ao_usb_init();
+
+	/* External hardware */
+	ao_storage_init();
 	ao_radio_init();
-
-	ao_fat_init();
-
 	ao_gps_init();
-	ao_gps_report_mega_init();
 
+	/* Services */
+	ao_log_init();
 	ao_telemetry_init();
-	ao_telemetry_set_interval(AO_SEC_TO_TICKS(1));
-	ao_rdf_set(1);
+	ao_tracker_init();
+
+	ao_led_off(AO_LED_GREEN);
 
-#if HAS_SAMPLE_PROFILE
-	ao_sample_profile_init();
-#endif
-	ao_config_init();
-	
 	ao_start_scheduler();
 	return 0;
 }
