@@ -619,7 +619,7 @@ public class TeleGPSConfigUI
 		return true;
 	}
 
-	void set_dirty() {
+	public void set_dirty() {
 		dirty = true;
 		save.setEnabled(true);
 	}
@@ -634,6 +634,17 @@ public class TeleGPSConfigUI
 		super.dispose();
 	}
 
+	public int accel_cal_plus() {
+		return AltosLib.MISSING;
+	}
+
+	public int accel_cal_minus() {
+		return AltosLib.MISSING;
+	}
+
+	public void set_accel_cal(int accel_plus, int accel_minus) {
+	}
+
 	/* Listen for events from our buttons */
 	public void actionPerformed(ActionEvent e) {
 		String	cmd = e.getActionCommand();
