@@ -20,8 +20,8 @@ package org.altusmetrum.telegps;
 
 import java.awt.*;
 import javax.swing.*;
-import org.altusmetrum.altoslib_11.*;
-import org.altusmetrum.altosuilib_11.*;
+import org.altusmetrum.altoslib_12.*;
+import org.altusmetrum.altosuilib_12.*;
 
 public class TeleGPSStatus extends JComponent implements AltosFlightDisplay {
 	GridBagLayout	layout;
@@ -75,11 +75,14 @@ public class TeleGPSStatus extends JComponent implements AltosFlightDisplay {
 		String	call;
 
 		void show(AltosState state, AltosListenerState listener_state) {
-			if (state.callsign != call) {
-				value.setText(state.callsign);
-				call = state.callsign;
+			AltosCalData cal_data = state.cal_data();
+			if (cal_data == null)
+				System.out.printf("null cal data?\n");
+			if (cal_data.callsign != call) {
+				value.setText(cal_data.callsign);
+				call = cal_data.callsign;
 			}
-			if (state.callsign == null)
+			if (cal_data.callsign == null)
 				setVisible(false);
 			else
 				setVisible(true);
@@ -100,12 +103,13 @@ public class TeleGPSStatus extends JComponent implements AltosFlightDisplay {
 	class Serial extends Value {
 		int	serial = -1;
 		void show(AltosState state, AltosListenerState listener_state) {
-			if (state.serial != serial) {
-				if (state.serial == AltosLib.MISSING)
+			AltosCalData cal_data = state.cal_data();
+			if (cal_data.serial != serial) {
+				if (cal_data.serial == AltosLib.MISSING)
 					value.setText("none");
 				else
-					value.setText(String.format("%d", state.serial));
-				serial = state.serial;
+					value.setText(String.format("%d", cal_data.serial));
+				serial = cal_data.serial;
 			}
 		}
 
@@ -126,12 +130,13 @@ public class TeleGPSStatus extends JComponent implements AltosFlightDisplay {
 		int	last_flight = -1;
 
 		void show(AltosState state, AltosListenerState listener_state) {
-			if (state.flight != last_flight) {
-				if (state.flight == AltosLib.MISSING)
+			AltosCalData cal_data = state.cal_data();
+			if (cal_data.flight != last_flight) {
+				if (cal_data.flight == AltosLib.MISSING)
 					value.setText("none");
 				else
-					value.setText(String.format("%d", state.flight));
-				last_flight = state.flight;
+					value.setText(String.format("%d", cal_data.flight));
+				last_flight = cal_data.flight;
 			}
 		}
 
